Basic Nelson\Nygaard Plot Theme

nn_basic_theme(
  legend_right = FALSE,
  grey_background = TRUE,
  base_size = 12,
  base_family = "Barlow",
  base_line_size = base_size/170,
  base_rect_size = base_size/170
)

Arguments

legend_right

Legend defaults to top, if you want on right, set this parameter

grey_background

By default, these plots have a light grey background. Set to FALSE to use white.

base_size

Base font size, defaults to 12

base_family

Base font family, defaults to Barlow

base_line_size

Base grid line size

base_rect_size

Base rectangle size