Create parallel lines at distance, assumes sf data frame input.

st_parallel_line(line_obj, coord_local, distance, forward = TRUE)

Arguments

line_obj

{sf} data frame

coord_local

EPSG code of local (planar) coordinate system

distance

Distance of parallel line, in specified planar coordinate system

forward

Direction of parallel line generation. Default is in forward direction, select FALSE if you want in other direction.

Value

{sf} data frame with transformed geometry (parallel lines per specifications)