Basic Nelson\Nygaard Plot Theme
nn_basic_theme(
legend_right = FALSE,
grey_background = TRUE,
base_size = 12,
base_family = "Barlow",
base_line_size = base_size/170,
base_rect_size = base_size/170
)Legend defaults to top, if you want on right, set this parameter
By default, these plots have a light grey background. Set to FALSE to use white.
Base font size, defaults to 12
Base font family, defaults to Barlow
Base grid line size
Base rectangle size