R/offset-lines.R
st_parallel_line.RdCreate parallel lines at distance, assumes sf data frame input.
st_parallel_line(line_obj, coord_local, distance, forward = TRUE){sf} data frame
EPSG code of local (planar) coordinate system
Distance of parallel line, in specified planar coordinate system
Direction of parallel line generation. Default is in forward direction, select FALSE if you want in other direction.
{sf} data frame with transformed geometry (parallel lines per specifications)